BOAVUS
======
Transparent Object-Oriented Approach to BIDS in Python.

Features
--------

- Pure Python

Installation
------------
Install won by running:

    pip install boavus

Requirements
------------
- Python 3.6
- bidso

License
-------
The project is licensed under the MIT license.
